function mh = ManholeModel(mh)
    % function mh = ManholeModel(mh)
    %
    % Use the manhole geometry, flow rates for exchange between zones, 
    % upstream concentration profile mh.C0, and time-step mh.dt specified
    % within a manhole struct (mh) to predict downstream concentrations
    % mh.C2 using a compartmental mixing model.
    
    % Ensure valid model inputs
    try % Check for negative zone volumes
        fn = fieldnames(mh);
        k = cellfun(@(x)x(1) == 'V', fn);
        for ii=find(k)'
            eval(sprintf('assert(mh.%s >= 0, ''Assertion failed. %s < 0.'')', fn{ii}, fn{ii}))
        end
    catch ME
        rethrow(addCause(ME, MException('MATLAB:ManholeModel:Volumes', 'Error check volume')))
    end
    try % Check for positive flow rates and mass-balance in and out of zones
        fn = fieldnames(mh);
        k = cellfun(@(x)x(1) == 'Q', fn);
        for ii=find(k)'
            eval(sprintf('assert(mh.%s >= 0, ''Assertion failed. %s < 0.'')', fn{ii}, fn{ii}))
        end
        assert(abs(mh.Q01 - mh.Qin) < 1e-8) % V0, 1e-8 to allow for slightly arounding errors
        assert(abs(mh.Q01 - (mh.Q12 + mh.Q13)) < 1e-8) % V1
        assert(abs((mh.Q12 + mh.Q32 + mh.Q42) - (mh.Qout)) < 1e-8) % V2
        assert(abs((mh.Q13 + mh.Q43) - (mh.Q32 + mh.Q34)) < 1e-8) % V3
        assert(abs((mh.Q34 + mh.Q54) - (mh.Q42 + mh.Q43 + mh.Q45)) < 1e-8) % V4
        assert(abs(mh.Q45 - mh.Q54) < 1e-8) % V5
    catch ME
        rethrow(addCause(ME, MException('MATLAB:ManholeModel:MassBalance', 'Error checking mass-balance')))
    end
    
    % Check time-step size is sufficiently small for flow rates compared to
    % zone sizes (model cannot take more flow out of a zone than the zone's
    % volume)
    fn = fieldnames(mh);
    fn = fn(cellfun(@(x)sum(x == 'Q') > 0, fn));
    for ii=1:length(fn)
        if length(fn{ii}) == 3
            for jj=1:2
                digit = fn{ii}(jj+1);
                if digit > 47 && digit < 58 && digit ~= '0' && digit ~= '2' 
                    VXfn = ['V' digit];
                    VX = mh.(VXfn);
                    if VX < mh.(fn{ii})*mh.dt
                        error('volume %s (%0.1e) not large enough for flow rate %s (%0.1e)!', VXfn, VX, fn{ii}, mh.(fn{ii})*mh.dt)
                    end
                end
            end
        end
    end
    
    % Zone concentrations
    C0 = mh.C0;
    C1 = zeros(size(C0));
    C3 = zeros(size(C0));
    C4 = zeros(size(C0));
    C5 = zeros(size(C0));

    % Run the compartmental model
    firstarrivaloffset=floor(mh.timedelay/mh.dt);
    for t=firstarrivaloffset+1:length(C0)
        if t == 1 % The first time-step only depends on the upstream data, not any of the other zones
            C1(t) = (mh.dt/mh.V1)*( mh.Q01*C0(t-firstarrivaloffset) ); % Modified Equation 31
        else
            C1(t) = (mh.dt/mh.V1)*( mh.Q01*C0(t-firstarrivaloffset) - C1(t-1)*(mh.Q12 + mh.Q13) ) + C1(t-1); % Equation 31
            C3(t) = (mh.dt/mh.V3)*( C1(t-1)*(mh.Q13) - C3(t-1)*(mh.Q32 + mh.Q34) + C4(t-1)*(mh.Q43) ) + C3(t-1); % Equation 32
            C4(t) = (mh.dt/mh.V4)*( C3(t-1)*(mh.Q34) - C4(t-1)*(mh.Q42 + mh.Q43 + mh.Q45) + C5(t-1)*(mh.Q54) ) + C4(t-1); % Equation 33
            
            if mh.V5 ~= 0 % Only needed if the high-surcharge storage zone exists
                C5(t) = (mh.dt/mh.V5)*( C4(t-1)*(mh.Q45) - C5(t-1)*(mh.Q54) ) + C5(t-1); % Equation 34
            end
        end
    end
    C2 = (mh.Q12.*C1 + mh.Q32.*C3 + mh.Q42.*C4) / mh.Qout; % Equation 35
    
    % Save zone concentrations to the manhole struct
    mh.C1 = C1;
    mh.C2 = C2;
    mh.C3 = C3;
    mh.C4 = C4;
    mh.C5 = C5;
