function PlotManhole(mh, individualzones)
    % function PlotManhole(mh, [individualzones]
    %
    % Plot the model output concentration profiles contained in a manhole
    % struct (mh). If individualzones is set to one, also plot the
    % concentrations shown in each zone. If the first data point of the
    % upstream profile is set to 1, this will be treated as a CRTD. If the
    % manhole struct contains the field C2recorded, this will also be
    % plotted as recorded downstream data for comparison.

    if ~exist('individualzones', 'var')
        individualzones = 0;
    end
    
    % Set all lines to be thick
    set(gcf, 'DefaultLineLineWidth', 1.2)
    
    % Plot the model output
    if isfield(mh, 'C2recorded')
        % Plot against recorded data if it exists
        plot(mh.time, [mh.C0 mh.C2recorded mh.C2])
        rt2 = RT2(mh.C2recorded, mh.C2);
    else
        if mh.C0(1) == 1 % plot CRTD
            plot(mh.time, cumsum(mh.C2))
        else % Plot just the model data
            plot(mh.time, [mh.C0 mh.C2])
        end
    end
    
    % Plot the zone concentrations
    if mh.C0(1) ~= 1 && individualzones == 1
        hold on
        h = plot(mh.time, [mh.C1 mh.C3 mh.C4 mh.C5]);
        hold off
        for jj=1:length(h); set(h(jj), 'LineStyle', '--'); end
    end

    % Axis limits and labels
    xlim(mh.time([1 end]))
    xlabel('Time (seconds)')
    if mh.C0(1) == 1
        ylabel('CRTD [-]')
    else
        ylabel('Relative Concentration [-]')
    end
    
    % Show legend
    if isfield(mh, 'C2recorded')
        leg = {'Upstream', 'Recorded DS', sprintf('Predicted DS\nRt2 = %0.3f', rt2)};
    else
        leg = {'Upstream', 'Downstream'};
    end
    if mh.C0(1) ~= 1 && individualzones == 1
        leg = [leg {'C1', 'C3', 'C4', 'C5', 'C6'}];
    end
    if mh.C0(1) ~= 1
        legend(leg)
    end
    
