# Code for a compartmental model for describing mixing in manholes

This package implements the compartmental mixing model described in the journal article *Predicting manhole mixing using a compartmental model* (Sonnenwald et al., submitted). This model uses jet theory to divide a manhole into multiple zones and work out the exchange between zones. Using these values, the model then uses compartmental mixing theory to predict downstream concentrations based on upstream concentrations. This document outlines running the model and how the code functions. The accompanying document *Further details and equations of a compartmental model for describing mixing in manholes* provides the theoretical background and equations used.

## 1 Getting Started

### 1.1 Prerequisites

  * MATLAB or GNU Octave. The code has been tested with MATLAB R2020a and Octave 5.2.0.
  * The code should be operating system independent. Provided that MATLAB or Octave runs, so should the code.

### 1.2 Usage

This package consists of a set of functions to demonstrate the compartmental mixing model for manholes. The majority of these functions are support functions for determining manhole geometry and exchange between model zones. The remaining functions are either for computing the model or displaying model results.

To get started quickly, look at the `modeldemo.m` file, which demonstrates the construction and running of the model. For any file, use the help function, e.g. by typing `help ManholeModel` in the command window, to obtain a description of the function. All units are fundamental SI units (e.g., meters).

## 2 Code outline

In general, this code is structured around defining the manhole geometry, calculating flow rates between zones, defining the upstream concentration profile, running the model, then plotting results.

### 2.1 The manhole struct

All manhole dimensions, variables, outputs, etc., are stored in a struct dubbed the manhole struct. This is returned from the `Manhole()` function which takes the pipe diameter, manhole diameter, surcharge depth, and flow rate as arguments. Optional arguments are the distance to measurement (the default is assumed to be at the inlet/outlet), the manhole angle (the default value is assumed to be 0, i.e., straight-through), and the difference in elevation between the inlet and outlet invert or manhole step (the default value is assumed to be 0, i.e., unstepped).

### 2.2 The manhole geometry

Creating the manhole struct using the `Manhole()` function assigns the specified dimensions to the manhole struct. The `function SetupManhole()` should then be run on the manhole struct. This will calculate the zone volumes and exchange between zones based on the defined manhole dimensions. The function will return an updated manhole struct.

Note, the code is currently only written for unbenched manholes.  The `geometry/` folder contains functions specific to unique geometries, such as the stepped and angled manholes. Functions for benched manholes can be written and added here, then called from `SetupManhole()`.

After determining zone volumes, `SetupManhole()` calls `FlowRates()` to determine the exchange between zones. `FlowRates()`, in turn, calls the appropriate function for the manhole to determine the flow rates. Both `SetupManhole()` and `FlowRates()` contain some elements that are common for the straight-through, stepped, and angled manholes this code covers. `FlowRates()` and the `geometry/` functions take the manhole struct as an argument and return an updated manhole struct.

#### 2.2.1 Checking the flow rates

The `PlotFlows()` function operates on the manhole struct and plots a block diagram showing the relationships between model zones, with the relative exchange between zones displayed. `PlotFlows()` can be run on the manhole struct at any point after calling `SetupManhole()`.

### 2.3 Upstream data

The `C0` field of the manhole struct (column vector) should be assigned an upstream concentration data time-series. The `dt` field of the struct (scalar) should be assigned the time-step of this data. Only uniform time-step data is supported. For convenient plotting, the `time` field (column vector) can be assigned to the matching time data, which should have the same dimension as `C0`.

Example code assigning a 0.025 second time-step to 75 seconds of upstream data that is a normal distribution centered on 15 seconds with a spread of 4 seconds to the manhole struct `mh`:

```octave
mh.dt = 0.025;
mh.time = (0:mh.dt:75)';
mh.C0 = (mh.dt / (4*sqrt(2*pi))) * exp(-0.5 * ((mh.time - 15)/4).^2);
```

Note, the model runs for the length of `C0`, so its length should be padded sufficiently to cover the downstream profile.

### 2.4 Running the model and results

The `ManholeModel()` function operates on and returns a manhole struct, using the assigned zone volumes, flow rates, and upstream data to calculate a predicted downstream profile. Downstream concentrations are placed in the `C2` field (column vector).

Note, before the model runs, checks are performed to help ensure the model is physically realistic. `ManholeModel()` will throw an error if there are any negative volumes, negative flow rates, or if the flows do not mass-balance.

#### 2.4.1 Plotting results

The `PlotManhole()` function will take a manhole struct as an argument and plot the upstream and downstream concentration profiles. If the manhole struct contains a `C2recorded` field (column vector), this will be treated as a recorded downstream concentration profile and be plotted against the predicted concentration profile `C2`. An R<sub>t</sub><sup>2</sup> value showing the goodness-of-fit between the predicted and recorded profiles will then be shown in the legend.


## 3 Authors

* **Dr Fred Sonnenwald**<sup>1</sup> - Theory development and coding - [ORCID 0000-0002-2822-0406](https://orcid.org/0000-0002-2822-0406)
* **Dr Ole Mark**<sup>2</sup> - Theory development
* **Prof Virginia Stovin**<sup>1</sup> - Theory development - [ORCID 0000-0001-9444-5251](https://orcid.org/0000-0001-9444-5251)
* **Prof Ian Guymer**<sup>1</sup> - Theory development - [ORCID 0000-0002-1425-5093](https://orcid.org/0000-0002-1425-5093)

<sup>1</sup>[Department of Civil and Structural Engineering](https://www.sheffield.ac.uk/civil), [The University of Sheffield](https://www.sheffield.ac.uk/), Sheffield, United Kingdom.

<sup>2</sup>[Krüger A/S](https://www.kruger.dk/english), Denmark.


## 4 Help

The model implemented in this package is described in *Predicting manhole mixing using a compartmental model* (Sonnenwald et al., submitted) and the included *Details and equations of a compartmental model for describing mixing in manholes* document.

Comments are also provided in line with the code. Other help may be available by directly contacting Fred Sonnenwald, but be aware that the resources available are minimal.


## 5 License

This project is licensed under the MIT License, see the [LICENSE.md](LICENSE.md) file for more details.


## 6 Acknowledgments

This work was funded by EPSRC Grant [EP/P012027/1](http://gow.epsrc.ukri.org/NGBOViewGrant.aspx?GrantRef=EP/P012027/1).
