function mh = SteppedFlowRates(mh)
    % function mh = SteppedFlowRates(mh)
    %
    % Use the manhole geometry specified within a manhole struct (mh) to
    % calculate the exchange between zones for a straight through, but
    % stepped, manhole
    
    constants

    % Increase for a larger outlet downstream
    if ~isfield(mh, 'effectiveDp')
        mh.effectiveDp = mh.Dp;
    else
        warning('Untested code')
    end
    
    outletarea = mh.effectiveDp^2*pi/4;
    
    if mh.Dm / mh.Dp < 1/(2*alpha2) % The jet core reaches the outlet
        
        Q12 = mh.Qin*(1 - 4*alpha2*mh.Dm/mh.Dp + 4*(alpha2*mh.Dm/mh.Dp)^2); % Equation 9
    
        % Check if the jet core overlaps with the outlet
        [~, coreoverlaparea] = CheckCircleOverlap(mh.jetcoreradius, mh.effectiveDp/2, mh.Dp/2, mh.Dp/2 - mh.step);
        jetarea = mh.jetcoreradius^2*pi;
        mh.Q12 = coreoverlaparea / jetarea * Q12; % Reduce Q12 by the fraction of the jet core that that overlaps the outlet
        mh.Q13 = mh.Qin - mh.Q12; % Equation 10
        
        % Check if the jet diffusion zone in the plane of the outlet
        % intersects with the stepped outlet
        [diffusionzoneoverlap, diffusionzoneoverlaparea] = CheckCircleOverlap(mh.Dp/2 + mh.Dm/m, mh.effectiveDp/2, ...
            mh.Dp/2, mh.Dp/2 - mh.step);
        
        if diffusionzoneoverlap == 0 % The jet diffusion zone and outlet do not overlap
            mh.Q42 = mh.Qout - mh.Q12; % Equation 21
        elseif diffusionzoneoverlap == 2 % Now that's an outlet.
            error('Equations and code for the jet diffusion zone occurring entirely within outlet need to be written')
        else % The entire or part of the outlet is in the jet diffusion zone
            % Q42 is calculated, assuming uniform flow through the outlet,
            % as the flow from the fraction of the outlet that is
            % overlapped by the jet diffusion zone
            mh.Q42 = mh.Qout * (outletarea - diffusionzoneoverlaparea - coreoverlaparea) / outletarea;
            if mh.Q42 <= 0  % This should occur when outletarea == diffusionzoneoverlaparea
                mh.Q42 = 0; % <= in case of slight rounding errors
            end
        end
        
        if -mh.Dp/2 - mh.Dm/m < - mh.Dp/2 - mh.step
            % This is Equation 14, but applied upside down with the step in
            % place of the surcharge
            mh.Q3c = mh.Qin*(2*alpha2*mh.Dm/mh.Dp)^2*(1-erf((alpha2*mh.Dm+mh.step)/(sqrt(2)*alpha2*mh.Dm)));
        else
            mh.Q3c = 0;
        end
        
        if mh.S < mh.Dm/m
            mh.Q3d = mh.Qin*(2*alpha2*mh.Dm/mh.Dp)^2*(1-erf((alpha2*mh.Dm+mh.S)/(sqrt(2)*alpha2*mh.Dm))); % Equation 14
        else
            mh.Q3d = 0;
        end

        mh.Q3 = mh.Qin*2*(alpha2*mh.Dm/mh.Dp)^2*...
            (4+(sqrt(2*pi)*(mh.Dp-2*alpha2*mh.Dm))/(alpha2*mh.Dm)); % Equation 12

    else % The jet core does not reach the outlet (a wide manhole)
        error('Equations and code for large stepped manholes need to be written')
    end
    
    
