% Demonstrate the compartmental mixing model predicting the CRTD and
% downstream mixing.

clear
addpath geometry/
constants

% Manhole inlet and outlet diameter (m)
Dp = 0.088;

% Manhole diameter (m)
Dm = 0.388;

% Manhole inlet and outlet flow rate (l/s)
Q = 0.001;

% Manhole outlet step offset (difference in elevation between inlet and outlet invert, m)
step = 0;

% Manhole outlet angle
angle = 0;

% Manhole surcharge level above inlet soffit (m)
S = 0.1*Dm;

% Distance from manhole inlet to upstream and downstream concentration
% measurement
toMeasurement = 0;

% Create a manhole struct (mh) and define the manhole geometry
mh = Manhole(Dp, Dm, S, Q, toMeasurement, angle, step);

% Process the manhole geometry to calculate the zone volumes and zone
% exchange flow rates
mh = SetupManhole(mh);

%%

% Nominal retention time - this is uses this to scale the predefined
% upstream profile and concentration profile duration
tn = mh.SystemV/mh.Qin;

% Define the time-step and duration for which the model will be run
mh.dt = 0.0025;
mh.time = (0:mh.dt:round(tn*5))';

clf

% Run through two sets of data, one to calculate the CRTD and one to show
% processing of an entire upstream concentration profile

for ii=1:2
    
    if ii == 1 % CRTD
        C0 = zeros(size(mh.time));
        C0(1) = 1;
    else % Concentration profile (normal distribution with mu = tn, sigma = tn/3)
        C0 = (mh.dt / ((tn/3)*sqrt(2*pi))) * exp(-0.5 * ((mh.time - tn)/(tn/3)).^2);
    end

    % Define the upstream data in the manhole struct
    mh.C0 = C0;

    % Run the model
    mh = ManholeModel(mh);

    % Plot the CRTD/concentration profiles
    if ii == 1
        subplot(2,2,1)
    else
        subplot(2,1,2)
    end
    PlotManhole(mh)
    
end

% Title the figure with the manhole geometry
h = title(sprintf('\\itD_p\\rm\\bf = %g mm, \\itD_m\\rm\\bf = %g mm, \\itS\\rm\\bf = %g mm, step = %g mm, \\itQ\\rm\\bf = %0.1f l/s, %g°', ...
    mh.Dp*1000, mh.Dm*1000, mh.S*1000, mh.step*1000, mh.Qin*1000, mh.angle));
set(h, 'Units', 'normalized');
pos = get(h, 'Position');
pos(2) = pos(2) + 1.43;
set(h, 'Position', pos);

% Plot a diagram showing exchange between model zones
subplot(2,2,2)
PlotFlows(mh, 0)

% Make the plot fullscreen
set(gcf, 'Position', get(0, 'screensize'))
